@@ -27,7 +27,22 @@ class connector:
 		if 'v' in kwargs:
 			self.verbose = True
 			print(self.BLUE + "Verbose activate." + self.DEFAULT)
-		print(self.GREEN + "Connector ready to use!" + self.DEFAULT)
+		print(self.GREEN + "Connector ready to use! " + self.BLUE + "(If you need some information : helper() - or thanos@42paris.fr)" + self.DEFAULT)
+
+	def helper(self):
+		print('All function available :')
+		print("\t- \"launcher([requests],[url],)\" -> Will launch the request on url.")
+		print("\t- \"get([url])\" -> Will return the data of the get url.")
+		print("\t- \"post([url],['body'])\" -> Will post the body on the url.")
+		print("\t- \"patch([url],['body'])\" -> Will patch url with the body.")
+		print("\t- \"delete([url])\" -> Will delete url.")
+		print("\t- \"put_in_file([data],[*name])\" -> Will put the data in file, if name param was given, file will take the name, else file will be name output.json.")
+		print("\t- \"build_list_email([lst_login])\" -> Will build list of email (login@student.42.fr) more display all the login of given list.")
+		print("\t- \"get_login([id])\" -> Print login & return login for given id.")
+		print("\t- \"get_id([login])\" -> Print id & return id for given login.")
+		print("\t- \"get_private_email([login])\" -> Print email & return email for given login.")
+		print("\t- \"change_password([login],[new_password])\" -> Change password for given login.")
+
 
 	def dot_env_parser(self):
 		ret = {}
@@ -150,13 +165,37 @@ class connector:
 		return (json.loads(reply.text))
 
 	def build_list_email(self, all_logins):
-	print("[", end='')
-	i = 0
-	for login in all_logins:
-		print("\""+ login + "@student.42.fr\"", end='')
-		if i != len(all_logins) - 1:
-			print(",",end='')
-		i+=1
-	print("]")
-	for login in all_logins:
-		print(login)
+		print("[", end='')
+		i = 0
+		for login in all_logins:
+			print("\""+ login + "@student.42.fr\"", end='')
+			if i != len(all_logins) - 1:
+				print(",",end='')
+			i+=1
+		print("]")
+		for login in all_logins:
+			print(login)
+
+	def get_login(self, id):
+		url = f"/users/{id}"
+		data = self.get(url)
+		print(ret['login'])
+		return (ret['login'])
+
+	def get_id(self, login):
+		url = f"/users/{login}"
+		data = self.get(url)
+		print((((data['cursus_users'])[0])['user'])['id'])
+		return((((data['cursus_users'])[0])['user'])['id'])
+
+	def get_private_mail(self, login):
+		url = f"/users/{login}/user_candidature"
+		data = self.get(url)
+		print(data['email'])
+		return(data['email'])
+
+	def change_password(self, login, new_password):
+		url = f"/users/{login}?user[password]={new_password}"
+		body = None
+		data = self.patch(url, body=body)
+		return (data)
